/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import ClayButton from '@clayui/button';
import ClayForm, {ClayInput} from '@clayui/form';
import {ReactFieldBase} from 'dynamic-data-mapping-form-field-type';
import {openSelectionDialog} from 'frontend-js-web';
import React, {useEffect, useState} from 'react';

const LayoutSelector = ({
	disabled,
	inputValue,
	itemSelectorURL,
	name,
	onChange,
	portletNamespace,
}) => {
	const [layout, setLayout] = useState(() => JSON.parse(inputValue || '{}'));

	useEffect(() => {
		setLayout(JSON.parse(inputValue || '{}'));
	}, [inputValue]);

	const handleClearClick = () => {
		setLayout({});
		onChange('');
	};

	const handleFieldChanged = (event) => {
		const selectedItem = event.selectedItem;

		if (selectedItem && selectedItem.layoutId) {
			setLayout(selectedItem);
			onChange(JSON.stringify(selectedItem));
		}
	};

	const handleItemSelectorTriggerClick = (event) => {
		event.preventDefault();

		openSelectionDialog({
			onSelect: handleFieldChanged,
			selectEventName: `${portletNamespace}selectLayout`,
			title: Liferay.Language.get('page'),
			url: itemSelectorURL,
		});
	};

	return (
		<ClayForm.Group style={{marginBottom: '0.5rem'}}>
			<ClayInput.Group>
				<ClayInput.GroupItem className="d-none d-sm-block" prepend>
					<input
						name={name}
						type="hidden"
						value={JSON.stringify(layout)}
					/>

					<ClayInput
						className="bg-light"
						disabled={disabled}
						onClick={handleItemSelectorTriggerClick}
						readOnly
						type="text"
						value={layout.name || ''}
					/>
				</ClayInput.GroupItem>

				<ClayInput.GroupItem append shrink>
					<ClayButton
						disabled={disabled}
						displayType="secondary"
						onClick={handleItemSelectorTriggerClick}
						type="button"
					>
						{Liferay.Language.get('select')}
					</ClayButton>
				</ClayInput.GroupItem>

				{layout.layoutId && (
					<ClayInput.GroupItem shrink>
						<ClayButton
							disabled={disabled}
							displayType="secondary"
							onClick={handleClearClick}
							type="button"
						>
							{Liferay.Language.get('clear')}
						</ClayButton>
					</ClayInput.GroupItem>
				)}
			</ClayInput.Group>
		</ClayForm.Group>
	);
};

const Main = ({
	itemSelectorURL,
	name,
	onChange,
	portletNamespace,
	predefinedValue,
	readOnly,
	value,
	...otherProps
}) => (
	<ReactFieldBase {...otherProps} name={name} readOnly={readOnly}>
		<LayoutSelector
			disabled={readOnly}
			inputValue={value && value !== '' ? value : predefinedValue}
			itemSelectorURL={itemSelectorURL}
			name={name}
			onChange={(value) => onChange({}, value)}
			portletNamespace={portletNamespace}
		/>
	</ReactFieldBase>
);

Main.displayName = 'LayoutSelector';

export default Main;
